@@ -1,5 +1,3 @@
-from django.core.management.base import BaseCommand, CommandError
-
 from . import FetchCommand
 from ...fetch.multifetchers import OriginalFilesMultiAccountFetcher
 
@@ -18,27 +16,28 @@ class Command(FetchCommand):
 
     help = "Fetches the original image files for one or all Flickr Accounts"
 
-    singular_noun = 'File'
-    plural_noun = 'Files'
+    singular_noun = "File"
+    plural_noun = "Files"
 
     def add_arguments(self, parser):
         super().add_arguments(parser)
 
         parser.add_argument(
-            '--all',
-            action='store_true',
+            "--all",
+            action="store_true",
             default=False,
-            help="Fetch ALL files, even if they've been downloaded before. Otherwise, only fetch files that haven't already been downloaded."
+            help=(
+                "Fetch ALL files, even if they've been downloaded before. "
+                "Otherwise, only fetch files that haven't already been downloaded."
+            ),
         )
 
     def handle(self, *args, **options):
         # We might be fetching for a specific account or all (None).
-        nsid = options['account'] if options['account'] else None;
+        nsid = options["account"] if options["account"] else None
 
-        results = self.fetch_files(nsid, options['all'])
-        self.output_results(results, options.get('verbosity', 1))
+        results = self.fetch_files(nsid, options["all"])
+        self.output_results(results, options.get("verbosity", 1))
 
     def fetch_files(self, nsid, fetch_all=False):
-        return OriginalFilesMultiAccountFetcher(nsid=nsid).fetch(
-                                                        fetch_all=fetch_all)
-
+        return OriginalFilesMultiAccountFetcher(nsid=nsid).fetch(fetch_all=fetch_all)
